This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
| int main(){ | |
| int n1, n2, sum; | |
| int *dN1, *dN2, *dSum; | |
| int size = sizeof(int); | |
| } |
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
| __global__ void getSum (int *n1, int *n2, int *sumData){ | |
| *sumData = *n1 + *n2; | |
| } |
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
| #include "cuda_runtime.h" | |
| #include "device_launch_parameters.h" | |
| #include <stdio.h> | |
| #include <stdlib.h> |
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
| hello_cuda<<<Dg,Db>>>(); |
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
| dim3 Dg; | |
| Dg.x = 2; | |
| Dg.y = 2; | |
| Dg.z = 1; | |
| // also can be written as | |
| // Dg(2,2,1); | |
| dim3 Db(2,4,2); |
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
| kernel_name<<<Dg,Db>>> |
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
| __global__ void helloCuda(int *num1, int *num2, int *sum){ | |
| printf("Hello World from CUDA GPU!\n"); | |
| *sum = *num1+*num2; | |
| } |
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
| #include "cuda_runtime.h" | |
| #include "device_launch_parameters.h" | |
| #include <stdio.h> | |
| #include <stdlib.h> | |
| #define N 200 | |
| void dataToArray(int* a, int n){ | |
| int i; |
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
| #include "cuda_runtime.h" | |
| #include "device_launch_parameters.h" | |
| #include <stdio.h> | |
| #include <stdlib.h> | |
| __global__ void getSum(int *n1, int *n2, int *sumData) { | |
| *sumData = *n1 + *n2; | |
| } |
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
| npm i -g @neutralinojs/neu |